@@ -14,6 +14,7 @@
 # limitations under the License.
 
 from zaqarclient.queues.v1 import queues
+from zaqarclient.queues.v2 import claim as claim_api
 from zaqarclient.queues.v2 import core
 from zaqarclient.queues.v2 import message
 
@@ -88,6 +89,10 @@ class Queue(queues.Queue):
         core.queue_purge(trans, req, self._name,
                          resource_types=resource_types)
 
+    def claim(self, id=None, ttl=None, grace=None,
+              limit=None):
+        return claim_api.Claim(self, id=id, ttl=ttl, grace=grace, limit=limit)
+
 
 def create_object(parent):
     return lambda args: Queue(parent, args["name"], href=args.get("href"),
